#------------------------------------------------------------------------------
# Copyright (c) 2017, Nucleic Development Team.
#
# Distributed under the terms of the Modified BSD License.
#
# The full license is in the file LICENSE, distributed with this software.
#------------------------------------------------------------------------------

FRUITY_THEME = {
    "python": {
        "comment": {
            "color": "#008800",
            "paper": "#0f140f",
            "font-style": "italic"
        },
        "single_quoted_string": {
            "color": "#0086d2"
        },
        "class_name": {
            "color": "#ffffff"
        },
        "function_method_name": {
            "color": "#ff0086",
            "font-weight": "bold"
        },
        "operator": {
            "color": "#ffffff"
        },
        "double_quoted_string": {
            "color": "#0086d2"
        },
        "triple_double_quoted_string": {
            "color": "#0086d2"
        },
        "decorator": {
            "color": "#ffffff"
        },
        "comment_block": {
            "color": "#008800",
            "paper": "#0f140f",
            "font-style": "italic"
        },
        "keyword": {
            "color": "#fb660a",
            "font-weight": "bold"
        },
        "triple_single_quoted_string": {
            "color": "#0086d2"
        },
        "unclosed_string": {
            "color": "#ffffff"
        },
        "highlighted_identifier": {
            "paper": "#333333"
        }
    },
    "settings": {
        "caret": "#ffffff",
        "color": "#ffffff",
        "paper": "#111111",
        "name": "fruity"
    }
}

FRUITY_THEME['enaml'] = FRUITY_THEME['python']
